#
# spec file for package php-pear-XML_Parser
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pear_name  XML_Parser

Name:           php-pear-XML_Parser
Version:        1.3.8
Release:        1.13
Summary:        XML parsing class based on PHP's bundled expat
License:        BSD-2-Clause
Group:          Development/Libraries/Other
URL:            https://pear.php.net/package/%{pear_name}
Source:         https://pear.php.net/get/%{pear_name}-%{version}.tgz
BuildRequires:  php-devel
BuildRequires:  php-pear
Requires:       php-pear
Provides:       php-pear(%{pear_name}) = %{version}
# PHP5 last used in openSUSE:Leap_42.3
Provides:       php5-pear-%{pear_name} = %{version}
Obsoletes:      php5-pear-%{pear_name} < %{version}
Provides:       php7-pear-%{pear_name} = %{version}
Obsoletes:      php7-pear-%{pear_name} < %{version}
BuildArch:      noarch

%description
This is an XML parser based on PHPs built-in xml extension.

It supports two basic modes of operation: "func" and "event". In "func" mode,
it will look for a function named after each element (xmltag_ELEMENT for start
tags and xmltag_ELEMENT_ for end tags), and in "event" mode it uses a set of
generic callbacks.

Since version 1.2.0 there's a new XML_Parser_Simple class that makes parsing of
most XML documents easier, by automatically providing a stack for the elements.
Furthermore its now possible to split the parser from the handler object, so
you do not have to extend XML_Parser anymore in order to parse a document with
it.

%prep
%setup -q -n %{pear_name}-%{version}
# move package.xml when needed
[ -f ../package.xml ] &&  mv ../package.xml . || :

%build

%install
%{__pear} install --nodeps --offline --packagingroot %{buildroot} package.xml
install -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{php_pear_gen_filelist}

%post
if [ "$1" = "1" ]; then
  # on "rpm -ivh"
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi
if [ "$1" = "2" ]; then
  # on "rpm -Uvh"
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi

%postun
if [ "$1" = "0" ]; then
  # on "rpm -e"
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name} || :
fi

%files -f %{name}.files
%docdir %{pear_docdir}
%exclude %{pear_metadir}/.??*
%exclude %{pear_testdir}

%changelog
* Thu Dec  5 2019 Arjen de Korte <suse+build@de-korte.org>
- make package PHP version independent
- update to 1.3.8
  - PR #5: Don't use is_resource() for xml_parser resources
- use correct macro to reference metadata (boo#1158112)
- clean-up spec, use https for downloading
- remove LICENSE file
* Wed Mar  7 2018 ecsos@opensuse.org
- fix rm -rf line in spec to remove .channels etc. in Factory also
* Mon Sep 11 2017 jweberhofer@weberhofer.at
- Cleaned up spec file
- Added license file
* Sat Aug 19 2017 ecsos@opensuse.org
- renamed package to php7-pear-xml_parser
* Tue Jun 27 2017 ecsos@opensuse.org
- update to 1.3.7
  - Fix E_STRICT message on PHP7
- update to 1.3.6
  - Fix broken package.xml
- update to 1.3.5
  - Add composer compatibility
* Fri Mar 21 2014 lars@linux-schulserver.de
- require php >= 5.3 for building
* Thu Dec 13 2012 lars@linux-schulserver.de
- update to 1.3.4:
  + Remove package.php from release
  + fix bug #16467 Unit tests are broken
  + fix Bug #17725 Patch Avoid deprecated eregi functions
- provide php-pear-xml_parser
- just require php-pear
* Thu May  6 2010 lars@linux-schulserver.de
- update to 1.3.2:
  + Fix Bug #9328: assigned by reference error in XML_RSS parse
  + add an AllTests.php for PHPUnit usage
* Fri Mar 13 2009 lars@linux-schulserver.de
- fix source file
* Tue Jan  6 2009 Richard Bos <rbos@opensuse.org> - 1.3.1
- update to version 1.3.1
- switch to BSD License
- switch to package.xml v2
- PEAR CS cleanup
- Fix Doc #13120: Mistake in example code
* Tue Jan  6 2009 Richard Bos <rbos@opensuse.org> - 1.2.8
- Make it build again
* Mon Dec 10 2007 lars@linux-schulserver.de
- initial version 1.2.8
